#include <err.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <err.h>

#include "arg.h"

char *argv0;

static void
usage(void)
{
	fprintf(stderr, "usage: %s "
	        "[-v] "
	        "[-h] "
	        "[file ...] "
	        "\n", argv0);
	exit(1);
}

/* input format: positions<TAB>shear_velocities */
static double
find_flux(FILE *f)
{
	int i = 0;
	double pos, vel, pos_prev, vel_prev, flux = 0.0;

	while (fscanf(f, "%lf\t%lf%*[^\n]", &pos, &vel) == 2) {
		if (i++ > 0)
			flux += (vel + vel_prev) / 2.0 * (pos - pos_prev);
		pos_prev = pos;
		vel_prev = vel;
	}
	if (i == 1)
		err(1, "could not read input data");

	return flux;
}

int
main(int argc, char *argv[])
{
	int i;
	FILE *fp;

#ifdef __OpenBSD__
	if (pledge("stdio rpath", NULL) == -1)
		err(2, "pledge failed");
#endif

	ARGBEGIN {
	case 'h':
		usage();
		break;
	case 'v':
		printf("%s-"VERSION"\n", argv0);
		return 0;
		break;
	default:
		usage();
	} ARGEND;

	if (argc > 0) {
		for (i = 0; i < argc; i++) {
			if (!(fp = fopen(argv[i], "r")))
				err(1, "fopen: %s", argv[i]);

			printf("%.17g\n", find_flux(fp));
			fclose(fp);
		}
	} else
		printf("%.17g\n", find_flux(stdin));

	return 0;
}
